==> jc-1.4.0.tar.gz: soot/javaToJimple/jj/types/JjTypeSystem__5fc.h <==
// public class soot.javaToJimple.jj.types.JjTypeSystem_c

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b9763057e799ff42 polyglot_ext_jl_types_TypeSystem__5fc
// @dep_class d3c905630f8d8cef soot_javaToJimple_jj_types_JjTypeSystem__5fc

// header file dependencies
// @dep_header polyglot_ext_jl_types_TypeSystem__5fc

#include "polyglot/ext/jl/types/TypeSystem__5fc.h"

#ifndef _JC_soot_javaToJimple_jj_types_JjTypeSystem__5fc_H_
#define _JC_soot_javaToJimple_jj_types_JjTypeSystem__5fc_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_javaToJimple_jj_types_JjTypeSystem__5fc$sub_refs	_jc_soot_javaToJimple_jj_types_JjTypeSystem__5fc$sub_refs;
typedef struct _jc_soot_javaToJimple_jj_types_JjTypeSystem__5fc$sub_nonrefs	_jc_soot_javaToJimple_jj_types_JjTypeSystem__5fc$sub_nonrefs;
typedef struct _jc_soot_javaToJimple_jj_types_JjTypeSystem__5fc$refs	_jc_soot_javaToJimple_jj_types_JjTypeSystem__5fc$refs;
typedef struct _jc_soot_javaToJimple_jj_types_JjTypeSystem__5fc$nonrefs	_jc_soot_javaToJimple_jj_types_JjTypeSystem__5fc$nonrefs;
typedef struct _jc_soot_javaToJimple_jj_types_JjTypeSystem__5fc$object	_jc_soot_javaToJimple_jj_types_JjTypeSystem__5fc$object;

typedef const struct _jc_soot_javaToJimple_jj_types_JjTypeSystem__5fc$vmethods	_jc_soot_javaToJimple_jj_types_JjTypeSystem__5fc$vmethods;
typedef const struct _jc_soot_javaToJimple_jj_types_JjTypeSystem__5fc$vtable	_jc_soot_javaToJimple_jj_types_JjTypeSystem__5fc$vtable;
typedef const struct _jc_soot_javaToJimple_jj_types_JjTypeSystem__5fc$vtype	_jc_soot_javaToJimple_jj_types_JjTypeSystem__5fc$vtype;

// Constructors
extern void _jc_soot_javaToJimple_jj_types_JjTypeSystem__5fc$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_javaToJimple_jj_types_JjTypeSystem__5fc$object *);

// Virtual methods structure
struct _jc_soot_javaToJimple_jj_types_JjTypeSystem__5fc$vmethods {
};

// Vtable
struct _jc_soot_javaToJimple_jj_types_JjTypeSystem__5fc$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_ext_jl_types_TypeSystem__5fc$vmethods	polyglot_ext_jl_types_TypeSystem__5fc;
	_jc_soot_javaToJimple_jj_types_JjTypeSystem__5fc$vmethods	soot_javaToJimple_jj_types_JjTypeSystem__5fc;
};

// Vtype
struct _jc_soot_javaToJimple_jj_types_JjTypeSystem__5fc$vtype {
	_jc_type			type;
	_jc_soot_javaToJimple_jj_types_JjTypeSystem__5fc$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_javaToJimple_jj_types_JjTypeSystem__5fc$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_javaToJimple_jj_types_JjTypeSystem__5fc$refs {
    _jc_soot_javaToJimple_jj_types_JjTypeSystem__5fc$sub_refs	soot_javaToJimple_jj_types_JjTypeSystem__5fc;
    _jc_polyglot_ext_jl_types_TypeSystem__5fc$sub_refs	polyglot_ext_jl_types_TypeSystem__5fc;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_javaToJimple_jj_types_JjTypeSystem__5fc$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_javaToJimple_jj_types_JjTypeSystem__5fc$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_ext_jl_types_TypeSystem__5fc$sub_nonrefs	polyglot_ext_jl_types_TypeSystem__5fc;
    _jc_soot_javaToJimple_jj_types_JjTypeSystem__5fc$sub_nonrefs	soot_javaToJimple_jj_types_JjTypeSystem__5fc;
};

// Object instance structure
struct _jc_soot_javaToJimple_jj_types_JjTypeSystem__5fc$object {
	_jc_soot_javaToJimple_jj_types_JjTypeSystem__5fc$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_javaToJimple_jj_types_JjTypeSystem__5fc$vtype	*vtype;
	_jc_soot_javaToJimple_jj_types_JjTypeSystem__5fc$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_javaToJimple_jj_types_JjTypeSystem__5fc$vtype _jc_soot_javaToJimple_jj_types_JjTypeSystem__5fc$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_javaToJimple_jj_types_JjTypeSystem__5fc, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_javaToJimple_jj_types_JjTypeSystem__5fc$class_object;

#endif	/* _JC_soot_javaToJimple_jj_types_JjTypeSystem__5fc_H_ */

==> jc-1.4.6.tar.gz: soot/javaToJimple/jj/types/JjTypeSystem__5fc.h <==
// public class soot.javaToJimple.jj.types.JjTypeSystem_c

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b9763057e799ff42 polyglot_ext_jl_types_TypeSystem__5fc
// @dep_class d3c905630f8d8cef soot_javaToJimple_jj_types_JjTypeSystem__5fc

// header file dependencies
// @dep_header polyglot_ext_jl_types_TypeSystem__5fc

#include "polyglot/ext/jl/types/TypeSystem__5fc.h"

#ifndef _JC_soot_javaToJimple_jj_types_JjTypeSystem__5fc_H_
#define _JC_soot_javaToJimple_jj_types_JjTypeSystem__5fc_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_javaToJimple_jj_types_JjTypeSystem__5fc$sub_refs	_jc_soot_javaToJimple_jj_types_JjTypeSystem__5fc$sub_refs;
typedef struct _jc_soot_javaToJimple_jj_types_JjTypeSystem__5fc$sub_nonrefs	_jc_soot_javaToJimple_jj_types_JjTypeSystem__5fc$sub_nonrefs;
typedef struct _jc_soot_javaToJimple_jj_types_JjTypeSystem__5fc$refs	_jc_soot_javaToJimple_jj_types_JjTypeSystem__5fc$refs;
typedef struct _jc_soot_javaToJimple_jj_types_JjTypeSystem__5fc$nonrefs	_jc_soot_javaToJimple_jj_types_JjTypeSystem__5fc$nonrefs;
typedef struct _jc_soot_javaToJimple_jj_types_JjTypeSystem__5fc$object	_jc_soot_javaToJimple_jj_types_JjTypeSystem__5fc$object;

typedef const struct _jc_soot_javaToJimple_jj_types_JjTypeSystem__5fc$vmethods	_jc_soot_javaToJimple_jj_types_JjTypeSystem__5fc$vmethods;
typedef const struct _jc_soot_javaToJimple_jj_types_JjTypeSystem__5fc$vtable	_jc_soot_javaToJimple_jj_types_JjTypeSystem__5fc$vtable;
typedef const struct _jc_soot_javaToJimple_jj_types_JjTypeSystem__5fc$vtype	_jc_soot_javaToJimple_jj_types_JjTypeSystem__5fc$vtype;

// Constructors
extern void _jc_soot_javaToJimple_jj_types_JjTypeSystem__5fc$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_javaToJimple_jj_types_JjTypeSystem__5fc$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_javaToJimple_jj_types_JjTypeSystem__5fc$vmethods {
};

// Vtable
struct _jc_soot_javaToJimple_jj_types_JjTypeSystem__5fc$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_ext_jl_types_TypeSystem__5fc$vmethods	polyglot_ext_jl_types_TypeSystem__5fc;
	_jc_soot_javaToJimple_jj_types_JjTypeSystem__5fc$vmethods	soot_javaToJimple_jj_types_JjTypeSystem__5fc;
};

// Vtype
struct _jc_soot_javaToJimple_jj_types_JjTypeSystem__5fc$vtype {
	_jc_type			type;
	_jc_soot_javaToJimple_jj_types_JjTypeSystem__5fc$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_javaToJimple_jj_types_JjTypeSystem__5fc$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_javaToJimple_jj_types_JjTypeSystem__5fc$refs {
    _jc_soot_javaToJimple_jj_types_JjTypeSystem__5fc$sub_refs	soot_javaToJimple_jj_types_JjTypeSystem__5fc;
    _jc_polyglot_ext_jl_types_TypeSystem__5fc$sub_refs	polyglot_ext_jl_types_TypeSystem__5fc;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_javaToJimple_jj_types_JjTypeSystem__5fc$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_javaToJimple_jj_types_JjTypeSystem__5fc$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_ext_jl_types_TypeSystem__5fc$sub_nonrefs	polyglot_ext_jl_types_TypeSystem__5fc;
    _jc_soot_javaToJimple_jj_types_JjTypeSystem__5fc$sub_nonrefs	soot_javaToJimple_jj_types_JjTypeSystem__5fc;
};

// Object instance structure
struct _jc_soot_javaToJimple_jj_types_JjTypeSystem__5fc$object {
	_jc_soot_javaToJimple_jj_types_JjTypeSystem__5fc$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_javaToJimple_jj_types_JjTypeSystem__5fc$vtype	*vtype;
	_jc_soot_javaToJimple_jj_types_JjTypeSystem__5fc$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_javaToJimple_jj_types_JjTypeSystem__5fc$vtype _jc_soot_javaToJimple_jj_types_JjTypeSystem__5fc$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_javaToJimple_jj_types_JjTypeSystem__5fc, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_javaToJimple_jj_types_JjTypeSystem__5fc$class_object;

#endif	/* _JC_soot_javaToJimple_jj_types_JjTypeSystem__5fc_H_ */
